from Bio import SeqIO
from Bio.SeqRecord import SeqRecord
from pandas import read_csv

m8_file_path = "alignment.m8"

similarity_matrix = read_csv(m8_file_path, sep="\t", names="query,target,fident,alnlen,mismatch,gapopen,qstart,qend,tstart,tend,evalue,bits,pident,nident,qlen,tlen,qcov,tcov".split(","))

query_ids = set(similarity_matrix["query"].values)
del similarity_matrix

localizations = read_csv("subcellular_localizations_from_swissprot_with_deeploc_mappings.csv") 
localizations = localizations[~localizations.accession.isin(query_ids)]
del query_ids

records = SeqIO.parse("swissprot.xml", "uniprot-xml")
accessions = set(localizations.accession)
sequences = {}

for record in records:
    if record.id in accessions:
        sequences[record.id] = record.seq

dataset = list()
for loc in localizations.values:
    current = SeqRecord(sequences[loc[0]], id=loc[0], description=".".join(loc[1].split(" ")) + "-U new_test_set")
    dataset.append(current)

SeqIO.write(dataset, "new_test_set_not_redundancy_reduced.fasta", "fasta")
