from pandas import read_csv

## First: clean up localizations; Only ECO:0000269!
swissprot_localizations = read_csv("subcellular_localizations_from_swissprot.csv")

# ECO:0000305 -- curator inference used in manual assertion -- IC
# ECO:0000250 -- sequence similarity evidence used in manual assertion -- ISS
# ECO:0000269 -- experimental evidence used in manual assertion -- EXP
# nan
# ECO:0000255 -- match to sequence model evidence used in manual assertion -- ISM
# ECO:0000303 -- author statement without traceable support used in manual assertion -- NAS

acceptable_evidence_code = 'ECO:0000269'
swissprot_localizations = swissprot_localizations[swissprot_localizations.evidence == acceptable_evidence_code]

## Second: change class based on mapping file (swissprot --> Deeploc)

swissprot_to_deeploc_mapping = read_csv("deeploc_mapping.csv")
swissprot_deeploc = swissprot_localizations.merge(swissprot_to_deeploc_mapping, left_on="location", right_on="swissprot", how="left")

## Third: fillter & remove any empty values or duplicates

swissprot_deeploc['location'] = swissprot_deeploc['deeploc']
swissprot_deeploc = swissprot_deeploc[['accession', 'location']]
swissprot_deeploc = swissprot_deeploc.dropna()
swissprot_deeploc.drop_duplicates(inplace=True, subset=['accession', 'location'])

## Fourth: drop all proteins which have >1 localization

swissprot_deeploc.drop_duplicates(inplace=True, subset=['accession'], keep=False)

## Save
swissprot_deeploc.to_csv("subcellular_localizations_from_swissprot_with_deeploc_mappings.csv", index=False)
